From: Greg KH <greg@kroah.com>
To: marcelo@conectiva.com.br
Cc: pcihpd-discuss@lists.sourceforge.net
Subject: [PATCH 6 of 6] PCI Hotplug build update

Hi,

Here's a patch against 2.4.19-pre1 for the PCI Hotplug subsystem that
adds support for the IBM and ACPI drivers to the build process.

thanks,

greg k-h



diff -Nru a/drivers/hotplug/Config.in b/drivers/hotplug/Config.in
--- a/drivers/hotplug/Config.in	Tue Feb 26 13:19:25 2002
+++ b/drivers/hotplug/Config.in	Tue Feb 26 13:19:25 2002
@@ -4,9 +4,11 @@
 mainmenu_option next_comment
 comment 'PCI Hotplug Support'
 
-dep_tristate 'Support for PCI Hotplug (EXPERIMENTAL)' CONFIG_HOTPLUG_PCI $CONFIG_DDFS $CONFIG_EXPERIMENTAL
+dep_tristate 'Support for PCI Hotplug (EXPERIMENTAL)' CONFIG_HOTPLUG_PCI $CONFIG_EXPERIMENTAL
 
-dep_tristate '  Compaq PCI Hotplug driver' CONFIG_HOTPLUG_PCI_COMPAQ $CONFIG_HOTPLUG_PCI
+dep_tristate '  Compaq PCI Hotplug driver' CONFIG_HOTPLUG_PCI_COMPAQ $CONFIG_HOTPLUG_PCI $CONFIG_X86
 dep_mbool '    Save configuration into NVRAM on Compaq servers' CONFIG_HOTPLUG_PCI_COMPAQ_NVRAM $CONFIG_HOTPLUG_PCI_COMPAQ
+dep_tristate '  IBM PCI Hotplug driver' CONFIG_HOTPLUG_PCI_IBM $CONFIG_HOTPLUG_PCI $CONFIG_X86_IO_APIC $CONFIG_X86
+dep_tristate '  ACPI PCI Hotplug driver' CONFIG_HOTPLUG_PCI_ACPI $CONFIG_ACPI $CONFIG_HOTPLUG_PCI
 
 endmenu
diff -Nru a/drivers/hotplug/Makefile b/drivers/hotplug/Makefile
--- a/drivers/hotplug/Makefile	Tue Feb 26 13:19:29 2002
+++ b/drivers/hotplug/Makefile	Tue Feb 26 13:19:29 2002
@@ -4,12 +4,14 @@
 
 O_TARGET	:= vmlinux-obj.o
 
-list-multi	:= cpqphp.o pci_hotplug.o
+list-multi	:= cpqphp.o pci_hotplug.o ibmphp.o pcihpacpi.o 
 
 export-objs	:= pci_hotplug_core.o pci_hotplug_util.o
 
 obj-$(CONFIG_HOTPLUG_PCI)		+= pci_hotplug.o
 obj-$(CONFIG_HOTPLUG_PCI_COMPAQ)	+= cpqphp.o
+obj-$(CONFIG_HOTPLUG_PCI_IBM)		+= ibmphp.o
+obj-$(CONFIG_HOTPLUG_PCI_ACPI)		+= pcihpacpi.o
 
 pci_hotplug-objs	:=	pci_hotplug_core.o	\
 				pci_hotplug_util.o
@@ -19,6 +21,22 @@
 				cpqphp_proc.o	\
 				cpqphp_pci.o
 
+ibmphp-objs		:=	ibmphp_core.o	\
+				ibmphp_ebda.o	\
+				ibmphp_pci.o	\
+				ibmphp_res.o	\
+				ibmphp_hpc.o
+
+ifdef CONFIG_HOTPLUG_PCI_ACPI
+  EXTRA_CFLAGS	+= -D_LINUX -I$(CURDIR)/../acpi
+  ifdef CONFIG_ACPI_DEBUG
+    EXTRA_CFLAGS += -DACPI_DEBUG -Wno-unused
+  endif
+endif
+
+pcihp_acpi_objs		:=	pcihp_acpi.o	\
+				pcihp_acpi_glue.o
+
 ifeq ($(CONFIG_HOTPLUG_PCI_COMPAQ_NVRAM),y)
 	cpqphp-objs += cpqphp_nvram.o
 endif
@@ -32,3 +50,8 @@
 cpqphp.o: $(cpqphp-objs)
 	$(LD) -r -o $@ $(cpqphp-objs)
 
+ibmphp.o: $(ibmphp-objs)
+	$(LD) -r -o $@ $(ibmphp-objs)
+
+pcihpacpi.o: $(pcihp_acpi_objs)
+	$(LD) -r -o $@ $(pcihp_acpi_objs)

